@@ -1,5 +1,8 @@
 package Sah::Schemas::CPAN;
 
+# during build by perl >= 5.014, Sah::SchemaR::cpan::pause_id will contain sequence (?^...) which is not supported by perl <= 5.012
+use 5.014;
+
 1;
 # ABSTRACT: Sah schemas related to CPAN
 
@@ -15,7 +18,7 @@ Sah::Schemas::CPAN - Sah schemas related to CPAN
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schemas::CPAN (from Perl distribution Sah-Schemas-CPAN), released on 2020-01-01.
+This document describes version 0.012 of Sah::Schemas::CPAN (from Perl distribution Sah-Schemas-CPAN), released on 2020-01-02.
 
 =head1 SYNOPSIS
 
